# -*- coding: utf-8 -*-

# Copyright (c) 2011-2017 CoNWeT Lab., Universidad Politécnica de Madrid

# This file is part of Wirecloud.

# Wirecloud is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# Wirecloud is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.

__version_info__ = (1, 1, 5)
__version__ = '.'.join(map(str, __version_info__))
__application_mashup_version_info__ = (2, 2)
__application_mashup_version__ = '.'.join(map(str, __application_mashup_version_info__))
__git_hash__ = "2a9519358434871a9d2a2e6fed29a7918f6ff6ed"
__git_dirty__ = True
__release_date__ = "Unknown"
